# EGit and Mylyn have circular dependencies
# EGit can build bootstrapped when Mylyn not present
%global bootstrap 0
%global version_suffix 201704051617-r

Name:             eclipse-egit
Version:          4.7.0
Release:          %mkrel 1
Group:            Development/Java
Summary:          Eclipse Git Integration

License:          EPL
URL:              http://www.eclipse.org/egit
Source0:          http://git.eclipse.org/c/egit/egit.git/snapshot/egit-%{version}.%{version_suffix}.tar.xz
%if %{bootstrap}
Patch0:           remove-mylyn-dep.patch
%endif

BuildRequires:    tycho
BuildRequires:    maven-antrun-plugin
BuildRequires:    eclipse-platform >= 1:4.6.0
BuildRequires:    eclipse-jdt
BuildRequires:    eclipse-jgit >= %{version}
BuildRequires:    eclipse-license
%if ! %{bootstrap}
BuildRequires:    eclipse-mylyn
BuildRequires:    eclipse-mylyn-docs-wikitext
%endif
Requires:         eclipse-platform >= 1:4.6.0
Requires:         eclipse-jgit >= %{version}

BuildArch:        noarch

%description
The eclipse-egit package contains Eclipse plugins for
interacting with Git repositories.

%if ! %{bootstrap}
%package mylyn
Summary:     Git integration for mylyn

%description mylyn
Git integration for mylyn.
%endif

%prep
%setup -q -n egit-%{version}.%{version_suffix}
%if %{bootstrap}
%patch0
%endif

%pom_xpath_remove "pom:repositories"
%pom_xpath_remove "pom:dependencies"
%pom_xpath_remove "pom:profiles"
%pom_xpath_remove "pom:build/pom:plugins/pom:plugin/pom:configuration/pom:target"
%pom_xpath_remove "*[local-name() ='plugin' and (child::*[text()='tycho-packaging-plugin'])]"
%pom_xpath_remove "pom:dependencies" org.eclipse.egit.doc/pom.xml
%pom_disable_module org.eclipse.egit.repository
%pom_disable_module org.eclipse.egit.source-feature
%pom_disable_module org.eclipse.egit.target
%pom_disable_module org.eclipse.egit.core.test
%pom_disable_module org.eclipse.egit.ui.test
%pom_disable_module org.eclipse.egit.ui.importer.tests
%pom_disable_module org.eclipse.egit.gitflow.test
%pom_disable_module org.eclipse.egit.mylyn.ui.test

%if %{bootstrap}
#to avoid mylyn circular dependancy
%pom_disable_module org.eclipse.egit.mylyn.ui
%pom_disable_module org.eclipse.egit.mylyn-feature
%endif

%mvn_package "::pom::" __noinstall
%if ! %{bootstrap}
%mvn_package :*mylyn* mylyn
%endif
%mvn_package :* egit

%build
%mvn_build -j -f

%install
%mvn_install

%files -f .mfiles-egit
%doc LICENSE README.md

%if ! %{bootstrap}
%files mylyn -f .mfiles-mylyn
%doc LICENSE README.md
%endif




%changelog
* Sun May 21 2017 neoclust <neoclust> 4.7.0-1.mga6
+ Revision: 1103983
- New version 4.7.0

* Wed Oct 05 2016 daviddavid <daviddavid> 4.5.0-1.mga6
+ Revision: 1058856
- Upgrade to 4.5.0

* Thu Aug 11 2016 daviddavid <daviddavid> 4.4.1-1.mga6
+ Revision: 1045542
- Upgrade to 4.4.1 (sync with fc24)

* Sun Jul 03 2016 daviddavid <daviddavid> 4.4.0-1.mga6
+ Revision: 1038403
- Update to latest release
- Add missing build-requires

* Wed May 04 2016 neoclust <neoclust> 4.3.0-2.mga6
+ Revision: 1009358
- Patch to build against smart import extension point that moved into Eclipse Neon platform.

* Sat Apr 30 2016 daviddavid <daviddavid> 4.3.0-1.mga6
+ Revision: 1008335
- Upgrade to 4.3.0

* Wed Mar 02 2016 neoclust <neoclust> 4.2.0-4.mga6
+ Revision: 982270
- Second rebuild of the java stack

* Sat Feb 27 2016 neoclust <neoclust> 4.2.0-3.mga6
+ Revision: 980124
- First rebuild of the java stack
- sync package eclipse-egit with fedora

  + pterjan <pterjan>
    - Restore

  + sander85 <sander85>
    - Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 3.1.0-4.mga5
+ Revision: 740962
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.1.0-3.mga5
+ Revision: 678938
- Mageia 5 Mass Rebuild
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 dmorgan <dmorgan> 3.1.0-1.mga4
+ Revision: 497225
- New version
- New version

* Sat Jan 19 2013 dmorgan <dmorgan> 2.2.0-1.mga3
+ Revision: 389589
- New version
- imported package eclipse-egit


* Tue Feb 22 2011 Chris Aniszczyk <zx@redhat.com> 0.11.3-2
- Update to fix issue with GitCloneWizard file.

* Tue Feb 22 2011 Chris Aniszczyk <zx@redhat.com> 0.11.3-1
- Update to upstream release 0.11.3.

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 22 2010 Chris Aniszczyk <zx@redhat.com> 0.10.1-1
- Update to upstream release 0.10.1.

* Thu Oct 7 2010 Chris Aniszczyk <zx@redhat.com> 0.9.3-1
- Update to upstream release 0.9.3.

* Wed Sep 15 2010 Severin Gehwolf <sgehwolf@redhat.com> 0.9.1-1
- Update to upstream release 0.9.1.
- Remove git-core dependency.

* Thu Aug 26 2010 Severin Gehwolf <sgehwolf at, redhat.com> 0.9.0-0.1.20100825git
- Make release tag more readable (separate "0.1" and pre-release tag by ".").

* Wed Aug 25 2010 Severin Gehwolf <sgehwolf at, redhat.com> 0.9.0-0.120100825git
- Pre-release of EGit 0.9.0

* Thu Jun 24 2010 Severin Gehwolf <sgehwolf at, redhat.com> 0.8.4-1
- Rebase to 0.8.4 release.

* Tue Apr 13 2010 Jeff Johnston <jjohnstn@redhat.com> 0.7.1-2
- Bump up release.

* Tue Apr 13 2010 Jeff Johnston <jjohnstn@redhat.com> 0.7.1-1
- Rebase to 0.7.1.

* Fri Mar 19 2010 Alexander Kurtakov <akurtako@redhat.com> 0.7.0-1
- Update to 0.7.0.
- License is only EPL now.

* Tue Feb 9 2010 Alexander Kurtakov <akurtako@redhat.com> 0.6.0-0.1.git20100208
- New git snapshot.

* Tue Nov 10 2009 Alexander Kurtakov <akurtako@redhat.com> 0.6.0-0.1.git20091029
- Update to 0.6 git.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Jul 17 2009 Alexander Kurtakov <akurtako@redhat.com> 0.5.0-1
- Update to 0.5.0.

* Mon Mar 23 2009 Alexander Kurtakov <akurtako@redhat.com> 0.4.0-3.20090323
- Update to latest snapshot.

* Mon Mar 23 2009 Alexander Kurtakov <akurtako@redhat.com> 0.4.0-3.20090217
- Rebuild to not ship p2 context.xml.

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.0-2.20090217
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Feb 17 2009 Alexander Kurtakov <akurtako@redhat.com> 0.4.0-1.20090217
- New snapshot.

* Wed Dec 10 2008 Alexander Kurtakov <akurtako@redhat.com> 0.4.0-1
- Update to 0.4.0.

* Wed Oct 22 2008 Alexander Kurtakov <akurtako@redhat.com> 0.3.1.20081022-3
- New git version.

* Wed Jul 30 2008 Andrew Overholt <overholt@redhat.com> 0.3.1-2
- Move files and update build for Eclipse SDK 3.4
- Use pdebuild

* Thu Jul 17 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.3.1-1
- fix license tag

* Tue Apr 08 2008 Jesse Keating <jkeating@redhat.com> - 0.3.1-0
- New upstream release 0.3.1, makes committing / diffing actually work

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.3.0-3
- Autorebuild for GCC 4.3

* Mon Oct 04 2007 Ben Konrath <bkonrath@redhat.com> 0.3.0-2.fc8
- Require git-core instead of git.
- Resolves: #319321

* Mon Sep 24 2007 Ben Konrath <bkonrath@redhat.com> 0.3.0-1.fc8
- 0.3.0

* Wed Sep 19 2007 Ben Konrath <bkonrath@redhat.com> 0.2.99-0.git20070919.fc8
- 0.2.99 git20070919

* Mon Sep 17 2007 Ben Konrath <bkonrath@redhat.com> 0.2.2-2.git20070911.fc8
- Update add feature and plugin patch.

* Mon Sep 17 2007 Ben Konrath <bkonrath@redhat.com> 0.2.2-1.git20070911.fc8
- Require eclipse-platform >= 3.2.1 

* Fri Sep 14 2007 Ben Konrath <bkonrath@redhat.com> 0.2.2-0.git20070911.fc8
- Update to git20070911.
- Update feature and accosicated branding plugin.

* Wed Aug 29 2007 Ben Konrath <bkonrath@redhat.com> 0.2.2-0.git20070826.fc8
- Initial version
